==> fleet-0.4.0.tar.gz: lib/fleet.dart <==
export 'src/animation/animatable_render_object_widget.dart'
    show
        AnimatableRenderObjectWidget,
        AnimatableSingleChildRenderObjectWidgetMixin;
export 'src/animation/animatable_stateless_widget.dart'
    show AnimatableStatelessWidget;
export 'src/animation/animate.dart'
    show Animated, AnimatingStateMixin, withAnimation;
export 'src/animation/animation.dart'
    show AnimationFromCurveExtension, AnimationSpec;
export 'src/animation/duration.dart' show DurationFromIntExtension;
export 'src/animation/parameter.dart'
    show
        AnimatableAlignmentGeometry,
        AnimatableBoxConstraints,
        AnimatableColor,
        AnimatableDecoration,
        AnimatableDouble,
        AnimatableEdgeInsetsGeometry,
        AnimatableInt,
        AnimatableMatrix4,
        AnimatableObject,
        AnimatableParameter,
        AnimatableParameterHost,
        AnimatableParameterHostMixin,
        AnimatableRect,
        AnimatableSize,
        OptionalAnimatableAlignmentGeometry,
        OptionalAnimatableBoxConstraints,
        OptionalAnimatableColor,
        OptionalAnimatableDecoration,
        OptionalAnimatableDouble,
        OptionalAnimatableEdgeInsetsGeometry,
        OptionalAnimatableInt,
        OptionalAnimatableMatrix4,
        OptionalAnimatableObject,
        OptionalAnimatableRect,
        OptionalAnimatableSize;
export 'src/common.dart' show Block;
export 'src/environment.dart' show EnvironmentKey, EnvironmentValueModifiers;
export 'src/widgets/basic_flutter_widgets.dart'
    show
        FleetAlign,
        FleetCenter,
        FleetColoredBox,
        FleetColumn,
        FleetColumnApplyChildren,
        FleetContainer,
        FleetFlex,
        FleetFlexApplyChildren,
        FleetIndexedStackApplyChildren,
        FleetOpacity,
        FleetPadding,
        FleetPositioned,
        FleetPositionedDirectional,
        FleetRow,
        FleetRowApplyChildren,
        FleetSizedBox,
        FleetSliverOpacity,
        FleetSliverPadding,
        FleetStackApplyChildren,
        FleetTransform,
        FleetWrapApplyChildren,
        defaultHorizontalMainAxisSize,
        defaultVerticalMainAxisSize;
export 'src/widgets/opinionated_defaults.dart' show OpinionatedDefaults;
export 'src/widgets/uniform_padding.dart'
    show Edge, Edges, UniformPadding, defaultUniformPadding;

==> fleet-0.5.0.tar.gz: lib/fleet.dart <==
export 'src/animation/animatable_render_object_widget.dart'
    show
        AnimatableRenderObjectWidget,
        AnimatableSingleChildRenderObjectWidgetMixin;
export 'src/animation/animatable_stateless_widget.dart'
    show AnimatableStatelessWidget;
export 'src/animation/animate.dart'
    show Animated, AnimatingStateMixin, withAnimation;
export 'src/animation/animation.dart'
    show AnimationFromCurveExtension, AnimationSpec;
export 'src/animation/duration.dart' show DurationFromIntExtension;
export 'src/animation/parameter.dart'
    show
        AnimatableAlignmentGeometry,
        AnimatableBoxConstraints,
        AnimatableColor,
        AnimatableDecoration,
        AnimatableDouble,
        AnimatableEdgeInsetsGeometry,
        AnimatableInt,
        AnimatableMatrix4,
        AnimatableObject,
        AnimatableParameter,
        AnimatableParameterHost,
        AnimatableParameterHostMixin,
        AnimatableRect,
        AnimatableSize,
        OptionalAnimatableAlignmentGeometry,
        OptionalAnimatableBoxConstraints,
        OptionalAnimatableColor,
        OptionalAnimatableDecoration,
        OptionalAnimatableDouble,
        OptionalAnimatableEdgeInsetsGeometry,
        OptionalAnimatableInt,
        OptionalAnimatableMatrix4,
        OptionalAnimatableObject,
        OptionalAnimatableRect,
        OptionalAnimatableSize;
export 'src/common.dart' show Block;
export 'src/environment.dart' show EnvironmentKey, EnvironmentValueModifiers;
export 'src/widgets/flutter/basic.dart'
    show
        FleetAlign,
        FleetAspectRatio,
        FleetCenter,
        FleetColoredBox,
        FleetColumn,
        FleetColumnApplyChildren,
        FleetConstrainedBox,
        FleetFittedBox,
        FleetFlex,
        FleetFlexApplyChildren,
        FleetFractionalTranslation,
        FleetFractionallySizedBox,
        FleetIndexedStackApplyChildren,
        FleetLimitedBox,
        FleetOpacity,
        FleetOverflowBox,
        FleetPadding,
        FleetPositioned,
        FleetPositionedDirectional,
        FleetRow,
        FleetRowApplyChildren,
        FleetSizedBox,
        FleetSizedOverflowBox,
        FleetSliverOpacity,
        FleetSliverPadding,
        FleetStackApplyChildren,
        FleetTransform,
        FleetWrapApplyChildren,
        defaultHorizontalMainAxisSize,
        defaultVerticalMainAxisSize;
export 'src/widgets/flutter/container.dart'
    show FleetContainer, FleetDecoratedBox;
export 'src/widgets/opinionated_defaults.dart' show OpinionatedDefaults;
export 'src/widgets/uniform_padding.dart'
    show Edge, Edges, UniformPadding, defaultUniformPadding;
